window.TVEAdmin = window.TVEAdmin || {};

window.TVEAdmin = (function () {
    var currentIframe = null;
    var currentId = null;
    var workingDir = window.location.href.substring(0, window.location.href.lastIndexOf('/')) + "/";

    var isControlsEnabled = function () {
        var controlsToggle = $('[name=toggle-controls]');

        return controlsToggle.is(':checked');
    };

    var isAutoplayEnabled = function() {
        var autoplayToggle = $('[name=autoplay]');

        return autoplayToggle.is(':checked');
    };

    var buildYoutubeUrl = function (id, bypassCheck) {
        if (!bypassCheck)
            if (id == '' || id == currentId)
                return;

        var YOUTUBE_VIDEO = 'https://www.youtube.com/embed/';
        var src = YOUTUBE_VIDEO + id + '?origin=' + window.location.protocol + '//' + window.location.host + '&enablejsapi=1&rel=0';

        src += '&autoplay=' + ((isAutoplayEnabled()) ? '1' : '0');

        if (!isControlsEnabled())
            src += '&showinfo=0&controls=0';

        currentId = id;

        return src;
    };

    var loadVideoById = function (id, bypassCheck, callback) {
        var url = null;

        if (id.match(/^[a-zA-Z0-9_-]{11}$/))
            url = buildYoutubeUrl(id, bypassCheck);

        $(currentIframe).attr('src', url);
        
        if(callback !== undefined) callback();
    };

    var iFrameAspectRatio = function () {
        currentIframe = $('.video-wrapper');

        if (currentIframe.length > 0) {
            currentIframe = currentIframe.get(0);
            var width = $(currentIframe).width();
            $(currentIframe).height(sixteenNineAspectRatio(width, 'width'));
        }
    };
    
    var sixteenNineAspectRatio = function(size, param) {
        if(param == 'width')
            return size * 9 / 16;
        
        return size * 16 / 9;
    };

    var getTemplateFromDir = function(name, callback) {
        $.get(workingDir + 'YouTubeFramework/templates/' + name + '_form.php', callback);
    };

    var loadTemplate = function (name, formattedName) {
        var overlayList = $('#overlays');
        var date = new Date();
        var timestamp = date.getTime();

        getTemplateFromDir(name, function (data) {
            $(overlayList).append('<div class="panel panel-default"><div class="panel-heading" role="tab" id="overlay-title-' + timestamp + '"><h4 class="panel-title"><a role="button" data-toggle="collapse" data-parent="#overlays" href="#overlay-' + timestamp + '" aria-expanded="true" aria-controls="overlay-' + timestamp + '">' + formattedName + '</a></h4></div><div id="overlay-' + timestamp + '" class="panel-collapse collapse in" role="tabpanel" aria-labelledby="overlay-title-' + timestamp + '"><div class="panel-body">' +
                    data + '</div></div></div>');
        });
    };

    var validateAndSave = function (id, data, arrayId) {
        var validator = new Validator();
        var isValid = validator.validate(data);

        if (isValid) {
            var type = $(data).filter('[name="overlay_type[' + id + ']"]').val();
            type = TVE.getUtils().capitalizeString(type);

            var layerBuilder = null;
            eval('layerBuilder = new ' + type + 'LayerBuilder(id, data);');

            var layer = layerBuilder.buildLayer();
            
            var insertedId = (arrayId == -1) ? TVE.addLayer(layer, currentId) : TVE.replaceLayer(layer, arrayId, currentId);

            /* Need to create a clone of the layer to remove DOM object and Overlay object 
             * in order to avoid recursion when serializing it. */
            var clone = TVE.getUtils().cloneObject(layer);
            clone.domElement = null;
            clone.overlay = null;
            var serializedObject = TVE.getUtils().serialize(clone);
            
            /* We store the serialized object to save it quickly */
            $(data).filter('[name="serialized_layer[' + id + ']"]').attr('value', btoa(serializedObject));
            
            $(data).filter('[name="overlay_type[' + id + ']"]').parent().find('.alert').fadeIn();
            setTimeout(function() {
                $(data).filter('[name="overlay_type[' + id + ']"]').parent().find('.alert').fadeOut();
            }, 1500);

            return insertedId;
        }

        return -1;
    };

    var Validator = function () {
        this.validate = function (fields) {
            var oneFailed = false;
            var context = this;

            $.each(fields, function (i, field) {
                var required = $(field).attr('required');
                var group = $(field).attr('data-group');
                var override = $(field).attr('data-override-hidden');
                var visible = $(field).is(':visible');

                if(!visible && override === undefined)
                    return;

                if (required !== undefined) {
                    var types = $(field).attr('data-validate');
                    types = (types !== undefined) ? types.split(',') : [undefined];
                    
                    for (var i = 0; i < types.length; i++) {
                        var type = types[i];
                        var isAValidField = context.validateField(field, type, false);

                        if (!isAValidField.test) {
                            var text = $(field).attr(isAValidField.selector);
                            $(field).parent().find('.help-block').css('display', 'block').html(text);
                            oneFailed = true;
                            break;
                        } else
                            $(field).parent().find('.help-block').css('display', 'none').html(null);
                    }
                }

                if (group !== undefined) {
                    var groupFields = $(fields).filter('[data-group=' + group + ']');
                    var everyOneEmpty = true;
                    
                    for(var i = 0; i < groupFields.length; i++) {
                        var field = groupFields[i];
                        if($(field).val() !== '')
                            everyOneEmpty = false;
                    }

                    if(everyOneEmpty) {
                        var text = $(groupFields).attr('data-group-error');
                        $(groupFields).parent().find('.help-block').css('display', 'block').html(text);
                        oneFailed = true;
                    } else {
                        $(groupFields).parent().find('.help-block').css('display', 'none');
                        
                        $.each(groupFields, function (i, field) {
                            if($(field).val() === '')
                                return;
                            
                            var types = $(field).attr('data-validate');
                            types = (types !== undefined) ? types.split(',') : [undefined];
                            
                            for (var i = 0; i < types.length; i++) {
                                var type = types[i];
                                var isAValidField = context.validateField(field, type, true);

                                if (!isAValidField.test) {
                                    var text = $(field).attr(isAValidField.selector);
                                    $(field).parent().find('.help-block').css('display', 'block').html(text);
                                    oneFailed = true;
                                    break;
                                } else
                                    $(field).parent().find('.help-block').css('display', 'none').html(null);
                            }
                        });
                    }
                }
            });

            return !oneFailed;
        };
        this.validateField = function (field, type, isGroupField) {
            if(!isGroupField) {
                var testVar = this.validateEmpty(field);
                if (!testVar.test)
                    return testVar;
            }

            if (type !== undefined) {
                eval('testVar = this.validate_' + type + '(field);');
                if (!testVar.test)
                    return testVar;
            }

            return {test: true, selector: ''};
        };
        this.validateEmpty = function (field) {
            var value = $(field).val();
            var test = value != '';
            var selector = 'data-error';
            return {test: test, selector: selector};
        };
        this.validate_url = function (field) {
            var value = $(field).val();
            var test = value.match(/https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#?&//=]*)/i);
            var selector = 'data-url-error';
            return {test: test, selector: selector};
        };
        this.validate_regexp = function (field) {
            var value = $(field).val();
            var regexp = $(field).attr('data-regexp');
            var regexpObj = new RegExp(regexp, 'i');
            var test = value.match(regexpObj);
            var selector = 'data-regexp-error';
            return {test: test, selector: selector};
        };
        this.validate_number = function (field) {
            var value = $(field).val();
            var test = value.match(/\d+/i);
            var selector = 'data-number-error';
            return {test: test, selector: selector};
        };
        this.validate_lesser = function (field) {
            return this.compareFields(field, 'lesser');
        };
        this.validate_greater = function (field) {
            return this.compareFields(field, 'greater');
        };
        this.compareFields = function (field, type) {
            var value = parseInt($(field).val());
            var otherValueSelector = $(field).attr('data-' + type + '-field');
            var otherValue = parseInt($('[name="' + otherValueSelector + '"]').val());
            var compareType = (type == 'lesser') ? '<' : '>';
            var test = false;

            eval('test = (value ' + compareType + ' otherValue)');

            var selector = 'data-' + type + '-error';
            return {test: test, selector: selector};
        };
    };

    /* Polymorphism GRASP Pattern */
    function LayerBuilder(id, data) {
        this.id = id;
        this.data = data;

        this.buildLayer = function () {
            var timings = this.calculateTimings();
            var html = this.buildHtml();
            var needPause = this.checkIfPause();
            var selector = this.getSelector();

            return this.buildSpecificObject(timings, html, needPause, selector);
        };

        this.calculateTimings = function () {
            var starting = $(this.data).filter('[name="start_at[' + this.id + ']"]').val();
            var startingMeasure = $(this.data).filter('[name="start_at_type[' + this.id + ']"]').val();
            var ending = $(this.data).filter('[name="stop_at[' + this.id + ']"]').val();
            var endingMeasure = $(this.data).filter('[name="stop_at_type[' + this.id + ']"]').val();

            var newStarting = (startingMeasure == 'min') ? parseInt(starting) * 60 : parseInt(starting);
            var newEnding = (endingMeasure == 'min') ? parseInt(ending) * 60 : parseInt(ending);

            var duration = newEnding - newStarting;

            return {start: newStarting, duration: duration};
        };

        this.buildHtml = function () {};

        this.checkIfPause = function () {
            return $(this.data).filter('[name="pause_video[' + this.id + ']"]').is(':checked');
        };

        this.getSelector = function () {};

        this.getPositions = function () {
            var vPosition = $(this.data).filter('[name="v_position[' + this.id + ']"]').val();
            var hPosition = $(this.data).filter('[name="h_position[' + this.id + ']"]').val();

            return {v: vPosition, h: hPosition};
        };

        this.buildSpecificObject = function (timings, html, needPause, selector) {
            return new TVE.DefaultLayer(html, timings.start, timings.duration, null, null, needPause, selector);
        };
    }

    function BannerLayerBuilder(id, data) {
        LayerBuilder.call(this, id, data);

        this.buildHtml = function () {
            var image = $(this.data).filter('[name="banner_url[' + this.id + ']"]').val();
            var url = $(this.data).filter('[name="banner_link[' + this.id + ']"]').val();
            var position = this.getPositions();

            return '<div class="position ' + position.v + ' ' + position.h + '"><img data-click data-href="' + url + '" src="' + image + '" class="img-responsive" /></div>';
        };

        this.getSelector = function () {
            return '[data-click]';
        };
    }

    BannerLayerBuilder.inherit(LayerBuilder);

    function SocialActionLayerBuilder(id, data) {
        LayerBuilder.call(this, id, data);

        this.buildHtml = function () {
            var text = $(this.data).filter('[name="social_text[' + this.id + ']"]').val();
            text = (text != '') ? '<div class="social-text"><b>' + text + '</b></div>' : '';
            var action = $(this.data).filter('[name="social_action[' + this.id + ']"]').val();
            var actionHtml = this.getSocialHtml(action);
            var position = this.getPositions();

            return '<div class="position ' + position.v + ' ' + position.h + '">' +
                    '<div class="social-wrapper">' +
                    text +
                    actionHtml +
                    '</div>' +
                    '</div>';
        };

        this.buildSpecificObject = function (timings, html, needPause, selector) {
            var popupData = {delay: 5000, width: 640, height: 480, scrollbars: 'no', resizable: 'no'};
            var callback = function(objWindow, context, pollTimer) {
                if (objWindow.closed !== false) {
                    clearInterval(pollTimer);

                    if (context.needPause)
                        setTimeout(function () {
                            context.hideAndPlay();
                        }, context.popupData.delay);
                    else
                        context.hideAndPlay();
                }
            };
            
            return new TVE.PopupLayer(html, timings.start, timings.duration, null, null, needPause, popupData, callback);
        };

        this.getSocialHtml = function (action) {
            var html = null;
            eval('html = this.get' + TVE.getUtils().capitalizeString(action) + 'Html();');

            return html;
        };

        this.getLikeHtml = function () {
            var facebookLike = $(this.data).filter('[name="facebook_like[' + this.id + ']"]').val();
            var twitterFollow = $(this.data).filter('[name="twitter_follow[' + this.id + ']"]').val();
            var gPlusFollow = $(this.data).filter('[name="gplus_follow[' + this.id + ']"]').val();
            var linkedInFollow = $(this.data).filter('[name="linkedin_follow[' + this.id + ']"]').val();
            var pinterestFollow = $(this.data).filter('[name="pinterest_follow[' + this.id + ']"]').val();

            var html = '<ul>';
            html += (facebookLike !== '') ? '<li><a class="btn btn-default btn-social facebook" data-popup href="' + facebookLike + '"><span class="fa fa-thumbs-up fa-lg"></span> Like</a></li>' : '';
            html += (twitterFollow !== '') ? '<li><a class="btn btn-default btn-social twitter" data-popup href="' + twitterFollow + '"><span class="fa fa-twitter fa-lg"></span> Follow</a></li>' : '';
            html += (gPlusFollow !== '') ? '<li><a class="btn btn-default btn-social gplus" data-popup href="' + gPlusFollow + '"><span class="fa fa-google-plus fa-lg"></span> Follow</a></li>' : '';
            html += (linkedInFollow !== '') ? '<li><a class="btn btn-default btn-social linkedin" data-popup href="' + linkedInFollow + '"><span class="fa fa-linkedin fa-lg"></span> Follow</a></li>' : '';
            html += (pinterestFollow !== '') ? '<li><a class="btn btn-default btn-social pinterest" data-popup href="' + pinterestFollow + '"><span class="fa fa-pinterest fa-lg"></span> Follow</a></li>' : '';
            html += '</ul>';
            
            return html;
        };

        this.getShareHtml = function () {
            var shareLink = $(this.data).filter('[name="share_link[' + this.id + ']"]').val();

            return '<ul>' +
                    '<li><a class="btn btn-default btn-social facebook" data-popup href="http://www.facebook.com/sharer.php?u=' + shareLink + '"><span class="fa fa-facebook-official fa-lg"></span> Share</a></li>' +
                    '<li><a class="btn btn-default btn-social twitter" data-popup href="http://twitter.com/share?url=' + shareLink + '"><span class="fa fa-twitter fa-lg"></span> Tweet</a></li>' +
                    '<li><a class="btn btn-default btn-social gplus" data-popup href="https://plus.google.com/share?url=' + shareLink + '"><span class="fa fa-google-plus fa-lg"></span> Share</a></li>' +
                    '<li><a class="btn btn-default btn-social linkedin" data-popup href="http://www.linkedin.com/shareArticle?mini=true&url=' + shareLink + '"><span class="fa fa-linkedin fa-lg"></span> Share</a></li>' +
                    '<li><a class="btn btn-default btn-social pinterest" data-popup href="http://pinterest.com/pin/create/button/?url=' + shareLink + '"><span class="fa fa-pinterest fa-lg"></span> Pin It</a></li>' +
                    '</ul>';
        };
    }

    SocialActionLayerBuilder.inherit(LayerBuilder);
    
    function CustomHtmlLayerBuilder(id, data) {
        LayerBuilder.call(this, id, data);

        this.buildHtml = function () {
            var html = $(this.data).filter('[name="custom_html[' + this.id + ']"]').val();
            
            return html;
        };

        this.getSelector = function () {
            return undefined;
        };
        
        this.buildSpecificObject = function (timings, html, needPause, selector) {
            return new TVE.FramedLayer(html, timings.start, timings.duration, null, null, false, true, false);
        };
    }

    CustomHtmlLayerBuilder.inherit(LayerBuilder);
    
    function SubscriptionFormLayerBuilder(id, data) {
        LayerBuilder.call(this, id, data);

        this.buildHtml = function () {
            var templateName = $(this.data).filter('[name="template_name[' + this.id + ']"]').val();
            var aweberList = $(this.data).filter('[name="aweber_lists[' + this.id + ']"]').val();
            var headlineMsg = $(this.data).filter('[name="headline_msg[' + this.id + ']"]').val();
            var thankYouMsg = $(this.data).filter('[name="thank_you_message[' + this.id + ']"]').val();
            
            var html = null;
            var script = null;
            
            $.ajax({
                url: workingDir + 'YouTubeFramework/templates/subscription_layouts/' + templateName + '.html',
                method: 'GET',
                dataType: 'html',
                async: false,
                cache: false,
                success: function(data) {
                    html = data;
                }
            });
            
            $.ajax({
                url: workingDir + 'YouTubeFramework/templates/subscription_layouts/subscribe_script.html',
                method: 'GET',
                dataType: 'html',
                async: false,
                cache: false,
                success: function(data) {
                    script = data;
                }
            });
            
            var baseLink = window.location.href.split('/'); baseLink.pop(); baseLink = baseLink.join('/');
            var completeLink = baseLink + '/YouTubeFramework/templates/subscription_layouts/';
            html = html.replace(/~BASELINK~/g, completeLink);
            html = html.replace(/~HEADLINE~/g, headlineMsg);
            
            script = script.replace(/~BASELINK~/g, baseLink);
            script = script.replace(/~THANKYOU~/g, thankYouMsg.replace(/'/g, "\\'"));
            script = script.replace(/~AWEBERLIST~/g, aweberList);
            
            html = html.replace(/~SCRIPTHERE~/g, script);
            
            return html;
        };
        
        this.buildSpecificObject = function (timings, html, needPause, selector) {
            return new TVE.FramedLayer(html, timings.start, 9007199254740992, null, null, true, false, true);
        };
    }

    SubscriptionFormLayerBuilder.inherit(LayerBuilder);
    
    function SellingUrlLayerBuilder(id, data) {
        LayerBuilder.call(this, id, data);
        this.sellingService = null;
        this.callback = null;

        this.buildHtml = function () {
            var productText = $(this.data).filter('[name="product_text[' + this.id + ']"]').val();
            this.sellingService = $(this.data).filter('[name="sale_service[' + this.id + ']"]').val();
            
            var enterTransaction = $(this.data).filter('[name="enter_transaction_text[' + this.id + ']"]').val();
            var checkTransaction = $(this.data).filter('[name="check_transaction_text[' + this.id + ']"]').val();
            var transactionTake = $(this.data).filter('[name="transaction_take_text[' + this.id + ']"]').val();

            var url = this.buildURLFromSelling();
            this.buildCallbackFromSelling();
            var position = this.getPositions();
            var modalHtml = '<div class="modal fade" data-transaction-modal id="transactionModal" tabindex="-1" role="dialog"><div class="modal-dialog" role="document" aria-labelledby="transactionModalLabel"><div class="modal-content"><div class="modal-body"><form><div class="form-group"><label for="transaction-id" class="control-label">' + enterTransaction + ':</label><input type="text" class="form-control" id="transaction-id" name="transaction-id" placeholder="' + enterTransaction + '"></div></form><i>(' + transactionTake + ')</i></div><div class="modal-footer"><button type="button" class="btn btn-primary" data-check-transaction>' + checkTransaction + '</button></div></div></div></div>';
            var banner = this.buildBannerFromSelling();

            return '<div class="position ' + position.v + ' ' + position.h + '"><div><a data-popup href="' + url + '"><img src="' + banner + '" class="img-responsive" /></a><p class="selling-text text-center"><b>' + productText + '</b></p></div></div>' + modalHtml;
        };
        
        this.buildBannerFromSelling = function() {
            if(this.sellingService == 'clickbank') 
                return 'https://support.clickbank.com/attachments/token/aegniu7p8lo4plm/?name=buy-now-logo_250x40.gif';
            else if(this.sellingService == 'jvzoo')
                return $(this.data).filter('[name="jvzoo_product_banner[' + this.id + ']"]').val();
        };
        
        this.buildURLFromSelling = function() {
            if(this.sellingService == 'clickbank') {
                var siteName = $(this.data).filter('[name="cb_site_uid[' + this.id + ']"]').val();
                var productId = $(this.data).filter('[name="clickbank_products[' + this.id + ']"]').val();
            
                return 'http://' + productId + '.' + siteName + '.pay.clickbank.net';
            } else if(this.sellingService == 'jvzoo') {
                var productUrl = $(this.data).filter('[name="jvzoo_product_link[' + this.id + ']"]').val();
                
                return productUrl;
            }
        };

        /* Code duplication is needed because callbacks are serialized, we can't do anything else! */
        this.buildCallbackFromSelling = function() {
            if(this.sellingService == 'clickbank') {
                this.callback = function(objWindow, context, pollTimer) {
                    clearInterval(pollTimer);
                    var canClose = false;
                    var transactionModal = $(context.domElement).find('[data-transaction-modal]');
                    var baseLink = window.location.href.split('/'); baseLink.pop(); baseLink = baseLink.join('/');
                    baseLink += '/';

                    if($('body').find('[data-transaction-modal]').length > 1) {
                        $('body').find('[data-transaction-modal]').remove();
                    }
                    $(transactionModal).detach().appendTo('body');
                    transactionModal = $('body').find('[data-transaction-modal]');
                    var eventInit = $(transactionModal).attr('data-ev-init') === 'true';
                    transactionModal.modal('show');
                    
                    if(!eventInit) {
                        transactionModal.on('hidden.bs.modal', function (e) {
                            if(canClose)
                                transactionModal.remove();
                        });

                        transactionModal.on('shown.bs.modal', function() {
                            context.removeListener();
                            context.setUpListener();
                        });

                        $(document).off('click', '[data-check-transaction]').on('click', '[data-check-transaction]', function() {
                            var clickContext = this;
                            var oldText = $(clickContext).html();
                            $(clickContext).html('<i class="fa fa-refresh fa-spin fa-fw"></i>');
                            var orderId = $($('[name=transaction-id]')).val();
                            var href = $('[data-popup]').attr('href');
                            var prodId = href.split('.')[0].replace(/http(s?):\/\//i, '');

                            $.ajax({
                                type: "POST",
                                url: baseLink + 'receipt_checker.php',
                                data: 'type=clickbank&receipt=' + orderId + '&product=' + prodId,
                                success: function (msg) {
                                    $(clickContext).html(oldText);

                                    if(msg === 'true') {
                                        canClose = true;
                                        transactionModal.modal('hide');
                                        context.hideAndPlay();
                                    }
                                }
                            });
                        });
                        
                        $(transactionModal).attr('data-ev-init', 'true');
                    }
                };
            } else if(this.sellingService == 'jvzoo') {
                this.callback = function(objWindow, context, pollTimer) {
                    clearInterval(pollTimer);
                    var canClose = false;
                    var transactionModal = $(context.domElement).find('[data-transaction-modal]');
                    var baseLink = window.location.href.split('/'); baseLink.pop(); baseLink = baseLink.join('/');
                    baseLink += '/';

                    if($('body').find('[data-transaction-modal]').length > 1) {
                        $('body').find('[data-transaction-modal]').remove();
                    }
                    $(transactionModal).detach().appendTo('body');
                    transactionModal = $('body').find('[data-transaction-modal]');
                    var eventInit = $(transactionModal).attr('data-ev-init') === 'true';
                    transactionModal.modal('show');
                    
                    if(!eventInit) {
                        transactionModal.on('shown.bs.modal', function() {
                            context.removeListener();
                            context.setUpListener();
                        });

                        transactionModal.on('hidden.bs.modal', function () {
                            if(canClose)
                                transactionModal.remove();
                        });

                        $(document).off('click', '[data-check-transaction]').on('click', '[data-check-transaction]', function() {
                            var clickContext = this;
                            var oldText = $(clickContext).html();
                            $(clickContext).html('<i class="fa fa-refresh fa-spin fa-fw"></i>');
                            var orderId = $($('[name=transaction-id]')).val();
                            var href = $('[data-popup]').attr('href').split('/');
                            var prodId = href[href.length - 1];

                            $.ajax({
                                type: "POST",
                                url: baseLink + 'receipt_checker.php',
                                data: 'type=jvzoo&receipt=' + orderId + '&product=' + prodId,
                                success: function (msg) {
                                    $(clickContext).html(oldText);

                                    if(msg === 'true') {
                                        canClose = true;
                                        transactionModal.modal('hide');
                                        context.hideAndPlay();
                                    }
                                }
                            });
                        });
                        
                        $(transactionModal).attr('data-ev-init', 'true');
                    }
                };
            }
        };

        this.buildSpecificObject = function (timings, html, needPause, selector) {
            var popupData = {width: 1280, height: 720, scrollbars: 'yes', resizable: 'yes'};
            
            return new TVE.PopupLayer(html, timings.start, 9007199254740992, null, null, true, popupData, this.callback);
        };
    }

    SellingUrlLayerBuilder.inherit(LayerBuilder);

    function EffectLayerBuilder(id, data) {
        LayerBuilder.call(this, id, data);

        this.buildHtml = function () {
            var effectName = $(this.data).filter('[name="effect_name[' + this.id + ']"]').val() + '.js';
            var baseLink = window.location.href.split('/'); baseLink.pop(); baseLink = baseLink.join('/');
            var completeLink = baseLink + '/YouTubeFramework/templates/effects/';
            var skipText = $(this.data).filter('[name="skip_text[' + this.id + ']"]').val();

            return '<div class="video-loader"><i class="fa fa-circle-o-notch fa-spin fa-3x fa-fw"></i></div><div style="display: none" data-src="' + completeLink + effectName + '"></div><canvas id="effect-canvas" width="1" height="1"></canvas><div class="row skip-effect"><div class="col-md-12 text-right"><a href="#!" data-skip>' + skipText + '</a></div></div>';
        };

        this.buildSpecificObject = function (timings, html, needPause, selector) {
            var duration = $(this.data).filter('[name="duration[' + this.id + ']"]').val();
            var durationMeasure = $(this.data).filter('[name="duration_type[' + this.id + ']"]').val();
            var newDuration = (durationMeasure == 'min') ? parseInt(duration) * 60 : parseInt(duration);

            var newSkipTimer = -1;
            if($(this.data).filter('[name="skip_effect[' + this.id + ']"]').is(':checked')) {
                var skipTimer = $(this.data).filter('[name="skip_effect_at[' + this.id + ']"]').val();
                var skipTimerMeasure = $(this.data).filter('[name="skip_effect_at_type[' + this.id + ']"]').val();
                newSkipTimer = (skipTimerMeasure == 'min') ? parseInt(skipTimer) * 60 : parseInt(skipTimer);
            }

            return new TVE.EffectLayer(html, timings.start, 9007199254740992, null, null, needPause, newDuration, newSkipTimer);
        };
    }

    EffectLayerBuilder.inherit(LayerBuilder);
    
    function StartScreenLayerBuilder(id, data) {
        LayerBuilder.call(this, id, data);

        this.buildHtml = function () {
            var url = $(this.data).filter('[name="image_url[' + this.id + ']"]').val();
            var useActual = $(this.data).filter('[name="use_actual_size[' + this.id + ']"]').is(':checked');
            
            var width = 0;
            var height = 0;
            var size = '';
            
            if(!useActual) {
                width = $(this.data).filter('[name="width[' + this.id + ']"]').val();
                height = $(this.data).filter('[name="height[' + this.id + ']"]').val();
                    
                if(width !== '' || height !== '') {
                    width = (width !== '') ? width + 'px' : ''; 
                    height = (height !== '') ? height + 'px' : '';
                    
                    size = 'background-size: ' + width + ' ' + height + ' !important';
                }
            } else {
                var imageTrick = $('<img id="image-trick" src="' + url + '" />');
                $(imageTrick).appendTo('body');
                
                width = $(imageTrick).width() + 'px';
                height = $(imageTrick).height() + 'px';
                
                size = 'background-size: ' + width + ' ' + height + ' !important';
                $('#image-trick').remove();
            }
            
            return '<div class="position"><div data-start-end style="background: url(' + url + '); ' + size + '"></div></div>';
        };
        
        this.buildSpecificObject = function (timings, html, needPause, selector) {
            return new TVE.StartScreenLayer(html, timings.duration, null, null, '(currentTime >= 0 && currentTime <= 0.5) && status == Video.states.playing');
        };
    }

    StartScreenLayerBuilder.inherit(LayerBuilder);
    
    function EndScreenLayerBuilder(id, data) {
        LayerBuilder.call(this, id, data);

        this.buildHtml = function () {
            var url = $(this.data).filter('[name="image_url[' + this.id + ']"]').val();
            var useActual = $(this.data).filter('[name="use_actual_size[' + this.id + ']"]').is(':checked');
            
            var width = 0;
            var height = 0;
            var size = '';
            
            if(!useActual) {
                width = $(this.data).filter('[name="width[' + this.id + ']"]').val();
                height = $(this.data).filter('[name="height[' + this.id + ']"]').val();
                    
                if(width !== '' || height !== '') {
                    width = (width !== '') ? width + 'px' : ''; 
                    height = (height !== '') ? height + 'px' : '';
                    
                    size = 'background-size: ' + width + ' ' + height + ' !important';
                }
            } else {
                var imageTrick = $('<img id="image-trick" src="' + url + '" />');
                $(imageTrick).appendTo('body');
                
                width = $(imageTrick).width() + 'px';
                height = $(imageTrick).height() + 'px';
                
                size = 'background-size: ' + width + ' ' + height + ' !important';
                $('#image-trick').remove();
            }
            
            return '<div class="position"><div data-start-end style="background: url(' + url + '); ' + size + '"></div></div>';
        };
        
        this.buildSpecificObject = function (timings, html, needPause, selector) {
            return new TVE.EndScreenLayer(html, timings.duration, null, null, 'status == Video.states.ended');
        };
    }

    EndScreenLayerBuilder.inherit(LayerBuilder);

    function CustomThumbLayerBuilder(id, data) {
        LayerBuilder.call(this, id, data);

        this.buildHtml = function () {
            var url = $(this.data).filter('[name="image_url[' + this.id + ']"]').val();
            
            var html = '<a href="#!" class="full-thumbnail" data-thumb-click><div style="background: url(' + url + ')" /></div></a>';
            
            return html;
        };
        
        this.buildSpecificObject = function (timings, html, needPause, selector) {
            return new TVE.CustomThumbnailLayer(html, null, null, 'status == Video.states.unstarted');
        };
    }

    CustomThumbLayerBuilder.inherit(LayerBuilder);

    return {
        loadVideoById: loadVideoById,
        iFrameAspectRatio: iFrameAspectRatio,
        sixteenNineAspectRatio: sixteenNineAspectRatio,
        loadTemplate: loadTemplate,
        validateAndSave: validateAndSave,
        getTemplateFromDir: getTemplateFromDir
    };
})();

$('[name=yt_id]').on('focusout', null, function () {
    var id = $(this).val();
    initVideoAdmin(id);
});

$('[name=toggle-controls]').on('switchChange.bootstrapSwitch', function (event, state) {
    var id = $('[name=yt_id]').val();
    initVideoAdmin(id);
});

$('[name=autoplay]').on('switchChange.bootstrapSwitch', function (event, state) {
    var id = $('[name=yt_id]').val();
    var customThumb = $('[name=use_custom_thumbnail]');
    if(state)
        if(customThumb.is(':checked'))
            customThumb.bootstrapSwitch('state', false);
    
    initVideoAdmin(id);
});

var initVideoAdmin = function(id) {
    var ytReadyTimerAdmin = setInterval(function() {
        if(YT.loaded) {
            clearInterval(ytReadyTimerAdmin);
            
            var lyt = $('[data-lyt]');
            lyt.attr('data-removing', '1');
            lyt.remove();

            TVEAdmin.loadVideoById(id, true, function() {
                TVE.init($('iframe'));

                var layers = $('[data-overlay-id]');
                layers.attr('data-remove', '');

                if(layers.length > 0)
                    $.each(layers, function(i, val) {
                        $(this).trigger('click');
                    });
            }); 
        }
    }, 200);
};

$('[name=use_start_screen]').on('switchChange.bootstrapSwitch', function (event, state) {
    var $startForm = $('[data-start-form]');
    
    if(state) {
        TVEAdmin.getTemplateFromDir('start_screen', function(data) {
            $startForm.empty().append(data);
        });
    } else {
        var button = $startForm.find('[data-overlay-id=start]');
        
        if(button.length > 0) {
            removeOverlay(button);
            button.attr('data-remove', '');
        }
        
        $startForm.html(null);
    }   
});

$('[name=use_end_screen]').on('switchChange.bootstrapSwitch', function (event, state) {
    var $endForm = $('[data-end-form]');
    
    if(state) {
        TVEAdmin.getTemplateFromDir('end_screen', function(data) {
            $endForm.empty().append(data);
        });
    } else {
        var button = $endForm.find('[data-overlay-id=end]');
        
        if(button.length > 0) {
            removeOverlay(button);
            button.attr('data-remove', '');
        }
        
        $endForm.html(null);
    }   
});


$('[name=use_custom_thumbnail]').on('switchChange.bootstrapSwitch', function (event, state) {
    var $customThumbForm = $('[data-custthumb-form]');
    
    if(state) {
        TVEAdmin.getTemplateFromDir('custom_thumbnail', function(data) {
            $customThumbForm.empty().append(data);
        });
    } else {
        var button = $customThumbForm.find('[data-overlay-id=custom_thumbnail]');
        
        if(button.length > 0) {
            removeOverlay(button);
            button.attr('data-remove', '');
        }
        
        $customThumbForm.html(null);
    }   
});

$('[name=add_overlay]').on('click', null, function () {
    var oldText = $(this).html();
    $(this).html('<i class="fa fa-refresh fa-spin fa-fw"></i>');
    
    var overlayButton = $('[name=overlay_type_loader]');
    var templateName = $(overlayButton).val();
    var templateFName = $(overlayButton).find(":selected").html();

    TVEAdmin.loadTemplate(templateName, templateFName);

    $(this).html(oldText);
});

$(document).on('click', '.remove-overlay', function () {
    removeOverlay(this);
    $(this).parent().parent().parent().parent().parent().remove();
});

var removeOverlay = function(button) {
    var id = $(button).attr('data-remove-id');
    var removeId = $('[data-overlay-id=' + id + ']').attr('data-remove');
    var ytId = $('[name=yt_id]').val();

    var tinyMceEditor = tinymce.get(id);
    if(tinyMceEditor != null) tinyMceEditor.remove();
    
    if (removeId != '')
        TVE.removeLayer(removeId, ytId);
};

$(document).on('click', '[data-overlay-id]', function () {
    var id = $(this).attr('data-overlay-id');
    var arrayId = $(this).attr('data-remove');
    var tinyMceEditor = tinymce.get(id);
    
    arrayId = (arrayId == '') ? -1 : arrayId;

    var overlayValues = $(this).parent().parent().parent().find('input, select, textarea');
    if(tinyMceEditor != null) $(overlayValues).filter('[name="custom_html[' + id + ']"]').val(tinyMceEditor.getContent());
    
    var insertId = TVEAdmin.validateAndSave(id, overlayValues, arrayId);

    if (insertId >= 0) {
        $(this).attr('data-remove', insertId);
        $(this).html($(this).attr('data-edit'));
    }
});

$(document).on('click', '[data-need-pause]', function () {
    var id = $(this).attr('data-need-pause');
    var stopAt = $('[data-stop-at=' + id + ']');

    if ($(this).is(':checked')) {
        $(stopAt).hide();
        $('[name="stop_at[' + id + ']"]').val('9007199254740992');
        $('[name="stop_at[' + id + ']"]').attr('value', '9007199254740992');
    } else {
        $(stopAt).show();
        $('[name="stop_at[' + id + ']"]').val(null);
        $('[name="stop_at[' + id + ']"]').attr('value','');
    }
});

$(document).on('click', '[data-need-skip]', function () {
    var id = $(this).attr('data-need-skip');
    var stopAt = $('[data-skip-at=' + id + ']');

    if ($(this).is(':checked')) {
        $(stopAt).show();
        $('[name="skip_effect_at[' + id + ']"]').val('');
        $('[name="skip_effect_at[' + id + ']"]').attr('value', '');
    } else {
        $(stopAt).hide();
        $('[name="skip_effect_at[' + id + ']"]').val('-1');
        $('[name="skip_effect_at[' + id + ']"]').attr('value', '-1');
    }
});

$(document).on('change', '[data-activate-hidden]', function () {
    var selected = $(this).find(":selected");
    var id = $(selected).attr('data-hidden-value');
    
    if(id !== undefined) {
        $(this).parent().parent().parent().find('[data-hidden]').hide();
        var hiddenValues = $(this).parent().parent().parent().find('[data-hidden=' + id + ']');

        $(hiddenValues).show();
    } else
        $(this).parent().parent().parent().find('[data-hidden]').hide();
});

$(window).resize(function () {
    TVEAdmin.iFrameAspectRatio();
});

$(document).ready(function () {
    TVEAdmin.iFrameAspectRatio();
    var ytLayers = $('[name=yt_id]');
    
    if (ytLayers.length > 0) {
        var id = ytLayers.val();
        initVideoAdmin(id);

        $('[name=toggle-controls]').bootstrapSwitch();
        $('[name=autoplay]').bootstrapSwitch();
    }    
    
    $('[name=use_start_screen]').bootstrapSwitch();
    $('[name=use_end_screen]').bootstrapSwitch();
    $('[name=use_custom_thumbnail]').bootstrapSwitch();
    setIframeCode();
});

$('[name=iframe_width]').on('focusout', null, function () {
    var width = $(this).val();
    if(width.match(/\d+/i))
        setIframeCode('width');
});

$('[name=iframe_height]').on('focusout', null, function () {
    var height = $(this).val();
    if(height.match(/\d+/i))
        setIframeCode('height');
});

$(document).on('click', '[name=iframe_code]', function() { 
    this.select(); 
});

var setIframeCode = function(param) {
    var codeField = $('[name=iframe_code]');
    if(codeField.length > 0) {
        var code = codeField.attr('value');
        var widthInput = $('[name=iframe_width]');
        var heightInput = $('[name=iframe_height]');
        
        var width = widthInput.val();
        var height = heightInput.val();
        if(param == 'width') {
            height = TVEAdmin.sixteenNineAspectRatio(width, param);
            heightInput.attr('value', height);
            heightInput.val(height);
        }
        else if(param == 'height') {
            width = TVEAdmin.sixteenNineAspectRatio(height, param);
            widthInput.attr('value', width);
            widthInput.val(width);
        }
        
        code = code.replace(/width=\"\d+\"/, 'width="' + width + '"');
        code = code.replace(/height=\"\d+\"/, 'height="' + height + '"');
        
        codeField.attr('value', code);
    }
};

$(document).on('click', '[name=form_action]', function(e) { 
    e.preventDefault();
    $('#altauth_save_page').submit();
});