<?php
  require_once('altauth_lib.php');
  require_once('altauth_language.php');
  require_once('libs/aweber_api/aweber_api.php');

  // AWeber APP ID
  $appID = "YOUR AWEBER APP ID HERE";

  $integrations = load_integrations();
  $jvzoo = load_jvzoo();
  $cb = load_clickbank();
  $aweber = load_aweber();

  $path = preg_replace('/\/[^\/]+$/', '', $_SERVER['PHP_SELF']);

  if(count($aweber) > 0) {
    $connected = true;
  } else {
    $connected = false;
  }

  if(isset($_POST['save'])) {
    $integrations['jvzoo']['status'] = isset($_POST['enable_jvzoo']) ? "enabled" : "disabled";
    $integrations['clickbank']['status'] = isset($_POST['enable_cb']) ? "enabled" : "disabled";
    $integrations['aweber']['status'] = isset($_POST['enable_aweber']) ? "enabled" : "disabled";

    save_integrations($integrations);

    if(isset($_POST['jvzoo_secret'])) {
      $jvzoo['jvzoo_key'] = $_POST['jvzoo_secret'];
    }
    save_jvzoo($jvzoo);

    if(isset($_POST['cb_clerk_api_key']) && isset($_POST['cb_dev_api_key']) && isset($_POST['cb_site_name'])) {
      $cb['cb_clerk_api_key'] = $_POST['cb_clerk_api_key'];
      $cb['cb_dev_api_key'] = $_POST['cb_dev_api_key'];
      $cb['cb_site_name'] = $_POST['cb_site_name'];
      $cb['clickbank_key'] = $_POST['clickbank_key'];
    }
    save_clickbank($cb);

    save_aweber($aweber);
  }

  // connect to aweber account using the authorization code provided
  if(isset($_POST['connect'])) {
    if(isset($_POST['aweber_secret']) && trim($_POST['aweber_secret']) != '') {
      try {
        list($consumer_key, $consumer_secret, $access_key, $access_secret) = AWeberAPI::getDataFromAweberID($_POST['aweber_secret']);  

        $aweber['oauth_id'] = $_POST['aweber_secret'];
        $aweber['consumer_key'] = $consumer_key;
        $aweber['consumer_secret'] = $consumer_secret;
        $aweber['access_key'] = $access_key;
        $aweber['access_secret'] = $access_secret;

      } catch (AWeberAPIException $exc) {
          list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
      } catch (AWeberOAuthDataMissing $exc) {
          list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
      } catch (AWeberException $exc) {
          list($consumer_key, $consumer_secret, $access_key, $access_secret) = null;
      }

      if(!$access_secret) {
        $message = "Error";
      } else {
        save_aweber($aweber); 
        $connected = true; 
        $integrations['jvzoo']['status'] = isset($_POST['enable_jvzoo']) ? "enabled" : "disabled";
        $integrations['clickbank']['status'] = isset($_POST['enable_cb']) ? "enabled" : "disabled";
        $integrations['aweber']['status'] = "enabled";

        save_integrations($integrations);  
      }
    }
  }

  // disconnect from aweber account
  if(isset($_POST['disconnect'])) {
        $integrations['jvzoo']['status'] = isset($_POST['enable_jvzoo']) ? "enabled" : "disabled";
        $integrations['clickbank']['status'] = isset($_POST['enable_cb']) ? "enabled" : "disabled";
        $integrations['aweber']['status'] = "disabled";

        save_integrations($integrations);
        unlink('altauth_aweber.txt');
        $connected = false;
  }  

  require_once('parts/admin_header.php');
?>
  <h1 class="page-header">
        <?php echo __('integrations'); ?>
  </h1>
  <?php if(isset($message) && $message != '') echo $message; ?>
  <form class="form-horizontal" method=post name="IntegrationsForm" role="form">

    <div class="panel panel-default">
      <div class="panel-heading">
        <h3 class="panel-title"><?php echo __('jvzoo_integration'); ?></h3>
      </div>
      <div class="panel-body">
        <div class="form-group">
          <label class="control-label col-sm-3" for="enable_jvzoo"><?php echo __('enable_jvzoo'); ?>:</label>
          <div class="col-sm-4"> 
            <input type="checkbox" style="margin-top: 12px;" id="enable_jvzoo" name="enable_jvzoo" value="enable_jvzoo" <?php echo (isset($integrations['jvzoo']['status']) && $integrations['jvzoo']['status'] == 'enabled') ? 'checked' : '';?>>
          </div>
        </div>

        <div class="form-group">
          <label class="control-label col-sm-3" for="jvzoo_secret"><?php echo __('jvzoo_secret'); ?>:</label>
          <div class="col-sm-4"> 
            <input type="text" class="form-control" id="jvzoo_secret" name="jvzoo_secret" placeholder="<?php echo __('enter_jvzoo_secret'); ?>" value="<?php echo isset($jvzoo['jvzoo_key']) ? $jvzoo['jvzoo_key'] : ''?>">
          </div>
        </div>

        <div class="form-group">
          <div class="col-sm-12"> 
            <b><?php echo __('ipn_tip_product') ?>: http://<?php echo $_SERVER['HTTP_HOST']; ?><?php echo $path; ?>/altauth_jvzoo_ipn.php</b>
          </div>
        </div>

      </div>
    </div>  

    <div class="panel panel-default">
      <div class="panel-heading">
        <h3 class="panel-title"><?php echo __('cb_integration'); ?></h3>
      </div>
      <div class="panel-body">
          <i><?php echo __('cb_integration_tip') ?></i>
        <div class="form-group">
          <label class="control-label col-sm-3" for="enable_cb"><?php echo __('enable_cb'); ?>:</label>
          <div class="col-sm-4"> 
            <input type="checkbox" style="margin-top: 12px;" id="enable_cb" name="enable_cb" value="enable_cb" <?php echo (isset($integrations['clickbank']['status']) && $integrations['clickbank']['status'] == 'enabled') ? 'checked' : '';?>>
          </div>
        </div>

        <div class="form-group">
          <label class="control-label col-sm-3" for="cb_clerk_api_key"><?php echo __('cb_clerk_api_key'); ?>:</label>
          <div class="col-sm-4"> 
            <input type="text" class="form-control" id="cb_clerk_api_key" name="cb_clerk_api_key" placeholder="<?php echo __('cb_clerk_api_key'); ?>" value="<?php echo isset($cb['cb_clerk_api_key']) ? $cb['cb_clerk_api_key'] : ''?>">
          </div>
        </div>
          
          <div class="form-group">
            <label class="control-label col-sm-3" for="cb_dev_api_key"><?php echo __('cb_dev_api_key'); ?>:</label>
            <div class="col-sm-4"> 
              <input type="text" class="form-control" id="cb_dev_api_key" name="cb_dev_api_key" placeholder="<?php echo __('cb_dev_api_key'); ?>" value="<?php echo isset($cb['cb_dev_api_key']) ? $cb['cb_dev_api_key'] : ''?>">
            </div>
          </div>

            <div class="form-group">
            <label class="control-label col-sm-3" for="cb_site_name"><?php echo __('cb_site_name'); ?><br><?php echo __('cb_account_nick') ?>:</label>
            <div class="col-sm-4"> 
              <input type="text" class="form-control" id="cb_site_name" name="cb_site_name" placeholder="<?php echo __('cb_site_name'); ?>" value="<?php echo isset($cb['cb_site_name']) ? $cb['cb_site_name'] : ''?>">
            </div>
          </div>
          
            <div class="form-group">
            <label class="control-label col-sm-3" for="clickbank_key"><?php echo __('cb_secret'); ?>:</label>
            <div class="col-sm-4"> 
              <input type="text" class="form-control" id="clickbank_key" name="clickbank_key" placeholder="<?php echo __('cb_secret'); ?>" value="<?php echo isset($cb['clickbank_key']) ? $cb['clickbank_key'] : ''?>">
            </div>
          </div>
          
          <div class="form-group">
            <div class="col-sm-12"> 
              <b><?php echo __('ipn_tip') ?>: http://<?php echo $_SERVER['HTTP_HOST']; ?><?php echo $path; ?>/altauth_clickbank_ipn.php</b>
            </div>
          </div>
      </div>
    </div>         

    <div class="panel panel-default">
      <div class="panel-heading">
        <h3 class="panel-title"><?php echo __('aweber_integration'); ?></h3>
      </div>
      <div class="panel-body">
        <div class="form-group">
          <label class="control-label col-sm-3" for="enable_aweber"><?php echo __('enable_aweber'); ?>:</label>
          <div class="col-sm-4"> 
            <input type="checkbox" style="margin-top: 12px;" id="enable_aweber" name="enable_aweber" value="enable_aweber" <?php echo (isset($integrations['aweber']['status']) && $integrations['aweber']['status'] == 'enabled') ? 'checked' : '';?>>
          </div>
        </div>

        <?php
          if(!$connected) :
        ?>
        <div class="form-group">
          <label class="control-label col-sm-3" for="enable_aweber"><?php echo __('aweber_auth_link'); ?>:</label>
          <div class="col-sm-4"> 
            <a target="_blank" href="https://auth.aweber.com/1.0/oauth/authorize_app/<?php echo $appID; ?>"><?php echo __('get_authorization_code'); ?></a>
          </div>
        </div>
        <?php
          endif;
        ?>

        <div class="form-group">
          <label class="control-label col-sm-3" for="aweber_secret"><?php echo __('aweber_secret'); ?>:</label>
          <div class="col-sm-4"> 
            <?php 
              if($connected) :
            ?>
              <button class="btn btn-default" type="submit" name="disconnect" value="disconnect"><?php echo __('disconnect'); ?></button>
            <?php
              else :
            ?>
              <input type="text" class="form-control" id="aweber_secret" name="aweber_secret" placeholder="<?php echo __('enter_aweber_secret'); ?>" value="">
              <button type="submit" name="connect" class="btn btn-default" value="connect"><?php echo __('connect'); ?></button>
            <?php 
              endif;
            ?>
          </div>
        </div>
      </div>
    </div>  

 
    <div class="form-group"> 
      <div class="col-sm-9">
        <button type="submit" name="save" class="btn btn-default" value="Save"><?php echo __('save'); ?></button>
      </div>
    </div>
  </form>


<?php
  require_once('parts/admin_footer.php');

?>
