<?php
require_once('altauth_language.php');
require_once('libs/aweber_api/aweber_api.php');

define("DEBUG", 1);
define("LOG_FILE", "./altauth.log");

$passwd_file = '';

function is_admin($username)
{
	$admin_user = get_admin_user();

	return $username == $admin_user ? 1 : 0;
}

function get_admin_user() {
	// fetch the admin email or use the default 'admin' user
    if (file_exists("altauth_adminemail.txt")) {
    	$admin_user = trim(join('', file("altauth_adminemail.txt")));	
    } else {
    	$admin_user = "admin";
    }

	return $admin_user;	
}

function locate_passwd_file()
{
	global $passwd_file;
	
	if ($passwd_file != '') return $passwd_file;

	if( ! file_exists('.htaccess_old') )
		die(__('fail_locate_htaccess_old'));

	foreach ( file(".htaccess_old") as $line )
	{
		preg_match("/^AuthUserFile\\s+(\"?)([^\s\"]+)\\1/i", chop($line), $matches);
		if (! isset($matches[2])) continue;
		$passwd_file = $matches[2];
	}
	
	if (! $passwd_file)
		die(__('fail_authuserfile'));
	
	if (! file_exists($passwd_file))
		die(__('fail_htpasswd_not_found'));
	
	return $passwd_file;
}

function save_user($username, $password, $is_admin=false)
{
	if ( ! $username || ! $password)
		die(__('error_no_username_pwd'));

	$username = strtolower($username);
	
	$file = locate_passwd_file();
	$lines = file($file);	

	if ( isset($lines[0]) && preg_match('/\$apr1\$/', $lines[0]) )
		$myline = $username . ':' . crypt_apr1_md5($password, '') . "\n";
	else
		$myline = $username . ':' . crypt($password) . "\n";

	$fh = fopen($file, "w")
		or die(__('fail_create_file')." $file");
	
	$changed = false;
	
	$admin_user = get_admin_user();	
	
	foreach ($lines as $line)
	{
		$line = chop($line);
		if ( (strpos($line, "$username:") === 0) || ($is_admin && strpos($line, "$admin_user:")===0) )
		{
			fwrite($fh, $myline);
			$changed = true;
		}
		else
		{
			fwrite($fh, "$line\n");
		}
	}
	
	if (! $changed)
	{
		fwrite($fh, $myline);
	}
		
	fclose($fh);
}

function has_user($username)
{
	if ( ! $username )
		return 0;
	
	$passwd_file = locate_passwd_file();
	
	foreach (file($passwd_file) as $line)
	{
		if ( strpos($line, "$username:") === 0 )
			return 1;
	}
	
	return 0;
}

function delete_user($username)
{
	if ( ! $username )
		return;
	
	$files = array(locate_passwd_file(), "altauth_userdb.txt");
	
	foreach ($files as $file)
	{
		if ( ! file_exists($file) )continue;
		
		$file_array = file($file);
		
		$fh = fopen($file, "w+")
			or die(__('fail_create_file')." $file");
		
		foreach ($file_array as $line)
		{
			if ( preg_match("/^$username$/i", chop($line)) )continue;
			if ( preg_match("/^$username:/i", chop($line)) )continue;
			if ( preg_match("/^$username=/i", chop($line)) )continue;
			fwrite($fh, $line);
		}
		
		fclose($fh);
	}
}

function load_userdb()
{
	$userdb = array();
	
	$file = 'altauth_userdb.txt';
	
	if ( ! file_exists($file) )
		return $userdb;
	
	foreach (file($file) as $line)
	{
		list($email, $data) = preg_split('/=/', chop($line), -1);
		list($regdate, $regcode, $ip, $status, $name) = preg_split('/::/', $data, -1);
		$userdb[$email]['regdate'] = $regdate;
		$userdb[$email]['regcode'] = $regcode;
		$userdb[$email]['ip'] = preg_split('/,/', $ip, -1, PREG_SPLIT_NO_EMPTY);
		$userdb[$email]['status'] = $status;
		$userdb[$email]['name'] = $name;
	}
	
	return $userdb;
}

function save_userdb($userdb)
{
	$file = 'altauth_userdb.txt';
	$fh = fopen($file, "w+")
		or die(__('fail_cannot_write')." $file ".__('fail_cannot_write_2'));
	
	foreach( array_keys($userdb) as $key )
	{
		$regdate = isset($userdb[$key]['regdate']) ? $userdb[$key]['regdate'] : '';
		$regcode = isset($userdb[$key]['regcode']) ? $userdb[$key]['regcode'] : '';
		if (isset($userdb[$key]['ip'])) {
			sort($userdb[$key]['ip']);
			$ip = join(',', $userdb[$key]['ip']);
		} else {
			$ip = '';
		}
		$status = isset($userdb[$key]['status']) ? $userdb[$key]['status'] : '';
		$name = isset($userdb[$key]['name']) ? $userdb[$key]['name'] : '';
			
		
		fwrite($fh, "$key=$regdate::$regcode::$ip::$status::$name\n");
	}
	
	fclose($fh);
}

function crypt_apr1_md5($plainpasswd, $cryptpass) 
{
	if ( $cryptpass == "" ) 
		$salt = substr(str_shuffle("abcdefghijklmnopqrstuvwxyz0123456789"), 0, 8);
	else
		$salt = substr($cryptpass, 6, 8);
	
	$len = strlen($plainpasswd);
	$text = $plainpasswd.'$apr1$'.$salt;
	$bin = pack("H32", md5($plainpasswd.$salt.$plainpasswd));
	
	for($i = $len; $i > 0; $i -= 16) { $text .= substr($bin, 0, min(16, $i)); }
	for($i = $len; $i > 0; $i >>= 1) { $text .= ($i & 1) ? chr(0) : $plainpasswd{0}; }
	
	$bin = pack("H32", md5($text));
	
	for($i = 0; $i < 1000; $i++) 
	{
		$new = ($i & 1) ? $plainpasswd : $bin;
		if ($i % 3) $new .= $salt;
		if ($i % 7) $new .= $plainpasswd;
		$new .= ($i & 1) ? $bin : $plainpasswd;
		$bin = pack("H32", md5($new));
	}
	$tmp = "";
	for ($i = 0; $i < 5; $i++) 
	{
		$k = $i + 6;
		$j = $i + 12;
		if ($j == 16) $j = 5;
		$tmp = $bin[$i].$bin[$k].$bin[$j].$tmp;
	}
	
	$tmp = chr(0).chr(0).$bin[11].$tmp;
	$tmp = strtr(strrev(substr(base64_encode($tmp), 2)),
	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",
	"./0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz");
	
	return "$"."apr1"."$".$salt."$".$tmp;
}

// returns the selected method to use when registering (CODES, JVZOO, AWEBER, etc)
function is_registration_method_enabled($method) {
	$integrations = load_integrations();

	$method = strtolower($method);
	/*
	if(isset($integrations['jvzoo']['status']) && $integrations['jvzoo']['status'] == 'enabled') {
		return 'JVZOO';
	} else {
		return 'CODES';
	}
	*/
	return (isset($integrations[$method]['status']) && $integrations[$method]['status'] == 'enabled');

}

function load_integrations() {
$integrations = array();

$file = dirname(__FILE__) . '/altauth_integrations.txt';

if ( ! file_exists($file) )
  return $integrations;

foreach (file($file) as $line)
{
  list($integration, $status) = preg_split('/::/', chop($line), -1);
  $integrations[$integration]['status'] = $status;
}

return $integrations;
}

function save_integrations($integrations) {
	$file = dirname(__FILE__) . '/altauth_integrations.txt';
	$fh = fopen($file, "w+")
	  or die(__('fail_cannot_write')." $file ".__('fail_cannot_write_2'));

	foreach( array_keys($integrations) as $key )
	{
	  $status = isset($integrations[$key]['status']) ? $integrations[$key]['status'] : 'disabled';
	  
	  fwrite($fh, "$key::$status\n");
	}

	fclose($fh);    
}

function load_jvzoo() {
	$settings = array();

	$file = dirname(__FILE__) . '/altauth_jvzoo.txt';

	if ( ! file_exists($file) )
	  return $settings;

	foreach (file($file) as $line)
	{
	  $jvzoo_key = chop($line);
	  $settings['jvzoo_key'] = $jvzoo_key;
	}

	return $settings;    
}

function save_jvzoo($settings) {
	$file = dirname(__FILE__) . '/altauth_jvzoo.txt';
	$fh = fopen($file, "w+")
	  or die(__('fail_cannot_write')." $file ".__('fail_cannot_write_2'));

	$jvzoo_key = isset($settings['jvzoo_key']) ? $settings['jvzoo_key'] : '';
	fwrite($fh, "$jvzoo_key");

	fclose($fh);

}

function load_clickbank() {
	$settings = array();

	$file = dirname(__FILE__) . '/altauth_clickbank.txt';
        
	if ( ! file_exists($file) )
	  return $settings;

        
        $key2Value = array(0 => 'cb_clerk_api_key', 1 => 'cb_dev_api_key', 2 => 'cb_site_name', 3 => 'clickbank_key');
        $i = 0;

        foreach (file($file) as $line) {
            $settings[$key2Value[$i]] = chop($line);

            $i++;
        }

	return $settings;    
}

function save_clickbank($settings) {
	$file = dirname(__FILE__) . '/altauth_clickbank.txt';
	$fh = fopen($file, "w+")
	  or die(__('fail_cannot_write')." $file ".__('fail_cannot_write_2'));

	$clickbank_clerk_key = isset($settings['cb_clerk_api_key']) ? $settings['cb_clerk_api_key'] : '';
        $clickbank_dev_key = isset($settings['cb_dev_api_key']) ? $settings['cb_dev_api_key'] : '';
        $clickbank_site_name = isset($settings['cb_site_name']) ? $settings['cb_site_name'] : '';
        $clickbank_key = isset($settings['clickbank_key']) ? $settings['clickbank_key'] : '';
        
	fwrite($fh, "$clickbank_clerk_key\n");
        fwrite($fh, "$clickbank_dev_key\n");
        fwrite($fh, "$clickbank_site_name\n");
        fwrite($fh, "$clickbank_key\n");

	fclose($fh);

}

function save_aweber($settings) {
	$file = dirname(__FILE__) . '/altauth_aweber.txt';

	if( isset($settings['oauth_id']) && trim($settings['oauth_id']) != '' &&
		isset($settings['consumer_key']) && trim($settings['consumer_key']) != '' &&
		isset($settings['consumer_secret']) && trim($settings['consumer_secret']) != '' &&
		isset($settings['access_key']) && trim($settings['access_key']) != '' &&
		isset($settings['access_secret']) && trim($settings['access_secret']) != '' ) {

		$fh = fopen($file, "w+")
		  or die(__('fail_cannot_write')." $file ".__('fail_cannot_write_2'));

		$oauth_id = $settings['oauth_id'];
		$consumer_key = $settings['consumer_key'];
		$consumer_secret = $settings['consumer_secret'];
		$access_key = $settings['access_key'];
		$access_secret = $settings['access_secret'];
		$list = $settings['list'];
		fwrite($fh, "$oauth_id::$consumer_key::$consumer_secret::$access_key::$access_secret::$list\n");	
		fclose($fh);   	
	} 
	
}

function load_aweber() {
	$settings = array();

	$file = dirname(__FILE__) . '/altauth_aweber.txt';
	if ( ! file_exists($file) )
	  return $settings;

	foreach (file($file) as $line)
	{
		list($settings['oauth_id'], $settings['consumer_key'], $settings['consumer_secret'], $settings['access_key'], $settings['access_secret']) = preg_split('/::/', chop($line), -1);
	}
	
	return $settings;
}

function subscribe_aweber($name, $email, $list) {
	$integrations = load_integrations();
	$aweber = load_aweber();

	// check if AWeber integration is enabled and configured
	if( isset($integrations['aweber']) && $integrations['aweber']['status'] == 'enabled' && count($aweber) > 0 && $list != 0 ) {
	    try {
	      $aweber_conn = new AWeberAPI($aweber['consumer_key'], $aweber['consumer_secret']);
	      $account = $aweber_conn->getAccount($aweber['access_key'], $aweber['access_secret']);

	      $listURL = "/accounts/".$account->id."/lists/".$list;
	      $list = $account->loadFromUrl($listURL);
              
	      $params = array('email' => $email, 
	      				  'name' => $name,  
	      				  'ad_tracking' => 'littlescript');
	      $subscribers = $list->subscribers;
	      $new_subscriber = $subscribers->create($params);

	      return 'true';
	    } catch (Exception $ex) {
    		if(DEBUG == true) {
    			error_log(date('[Y-m-d H:i e] '). "AWeber Error: ". $ex->message . PHP_EOL, 3, LOG_FILE);
    		}

	    	if(preg_match("/Subscriber already subscribed/", $ex->message)) {
	    		return 'true';
	    	} else {
	    		return $ex->message;		
	    	}
	    }

	}

	return 'true';
}


?>
